==> weld-jsf-permalink-1.1.2.Final-sources.jar: org/jboss/weld/examples/permalink/CommentBoard.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.weld.examples.permalink;

import javax.enterprise.inject.Model;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Inject;

/**
 * @author Dan Allen
 */
public
@Model
class CommentBoard
{
   @Inject
   Repository repository;

   @Inject
   Comment comment;

   @Inject
   Blog blog;

   public Boolean post()
   {
      if (comment == null || blog == null)
      {
         return null;
      }

      BlogEntry entry = repository.getEntry(blog.getEntryId());
      if (entry == null)
      {
         return null;
      }

      comment.checkAuthor();

      repository.addComment(comment, entry);
      FacesContext ctx = FacesContext.getCurrentInstance();
      ctx.addMessage(null, new FacesMessage("Thanks for leaving a comment!"));
      // FIXME doesn't seem to be working; must investigate
      ctx.getExternalContext().getFlash().setKeepMessages(true);
      return true;
   }
}

==> weld-jsf-permalink-1.1.8.Final-sources.jar: org/jboss/weld/examples/permalink/CommentBoard.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.weld.examples.permalink;

import javax.enterprise.inject.Model;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Inject;

/**
 * @author Dan Allen
 */
@Model
public class CommentBoard {
    @Inject
    Repository repository;

    @Inject
    Comment comment;

    @Inject
    Blog blog;

    public Boolean post() {
        if (comment == null || blog == null) {
            return null;
        }

        BlogEntry entry = repository.getEntry(blog.getEntryId());
        if (entry == null) {
            return null;
        }

        comment.checkAuthor();

        repository.addComment(comment, entry);
        FacesContext ctx = FacesContext.getCurrentInstance();
        ctx.addMessage(null, new FacesMessage("Thanks for leaving a comment!"));
        // FIXME doesn't seem to be working; must investigate
        ctx.getExternalContext().getFlash().setKeepMessages(true);
        return true;
    }
}
